#!/bin/bash
set -Eeuo pipefail

bin/update_crates.sh --check

